@@ -1,19 +1,18 @@
 import unittest
-from zope.testing import doctest, doctestunit
-from collective.geo.contentlocations.tests import base
+import doctest
 import collective.geo.contentlocations.geomanager
 
 import zope.component
-import zgeo.geographer.geo
-import zgeo.geographer.interfaces
+import collective.geo.geographer.geo
+import collective.geo.geographer.interfaces
 import zope.annotation.interfaces
 import zope.annotation.attribute
 
 def setUp(test):
 
     zope.component.provideAdapter(
-            zgeo.geographer.geo.GeoreferencingAnnotator,
-            provides=zgeo.geographer.interfaces.IWriteGeoreferenced
+            collective.geo.geographer.geo.GeoreferencingAnnotator,
+            provides=collective.geo.geographer.interfaces.IWriteGeoreferenced
         )
 
     zope.component.provideAdapter(
@@ -22,15 +21,15 @@ def setUp(test):
         )
 
 def tearDown(test):
-    """This is the companion to setUp - it can be used to clean up the 
+    """This is the companion to setUp - it can be used to clean up the
     test environment after each test.
     """
-    
+
 def test_suite():
     return unittest.TestSuite((
 
         doctest.DocTestSuite(collective.geo.contentlocations.geomanager,
-                     setUp=setUp, 
+                     setUp=setUp,
                      tearDown=tearDown,
                      optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS,),
         ))
